@@ -16,15 +16,18 @@ class DbDataFrame {
   std::vector<std::string> names;
 
 public:
-  DbDataFrame(DbColumnDataSourceFactory* factory, std::vector<std::string> names, const int n_max_, const std::vector<DATA_TYPE>& types);
+  DbDataFrame(DbColumnDataSourceFactory* factory,
+              std::vector<std::string> names,
+              const int n_max_,
+              const std::vector<DATA_TYPE>& types);
   virtual ~DbDataFrame();
 
 public:
   void set_col_values();
   bool advance();
 
-  List get_data();
-  List get_data(std::vector<DATA_TYPE>& types);
+  cpp11::list get_data();
+  cpp11::list get_data(std::vector<DATA_TYPE>& types);
   size_t get_ncols() const;
 
 private:
