@@ -6,17 +6,17 @@
 
 // Construction ////////////////////////////////////////////////////////////////
 
-PqResult::PqResult(const DbConnectionPtr& pConn, const std::string& sql) :
+PqResult::PqResult(const DbConnectionPtr& pConn, const std::string& sql, const bool immediate) :
   DbResult(pConn)
 {
-  impl.reset(new DbResultImpl(pConn, sql));
+  impl.reset(new DbResultImpl(pConn, sql, immediate));
 }
 
 
 // Publics /////////////////////////////////////////////////////////////////////
 
-DbResult* PqResult::create_and_send_query(const DbConnectionPtr& con, const std::string& sql) {
-  return new PqResult(con, sql);
+DbResult* PqResult::create_and_send_query(const DbConnectionPtr& con, const std::string& sql, const bool immediate) {
+  return new PqResult(con, sql, immediate);
 }
 
 
